summaryrefslogtreecommitdiffstats
path: root/src/compiler/spirv/vtn_variables.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/compiler/spirv/vtn_variables.c')
-rw-r--r--src/compiler/spirv/vtn_variables.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/compiler/spirv/vtn_variables.c b/src/compiler/spirv/vtn_variables.c
index 50d1d3f4813..1e888bb8bbe 100644
--- a/src/compiler/spirv/vtn_variables.c
+++ b/src/compiler/spirv/vtn_variables.c
@@ -1556,8 +1556,8 @@ apply_var_decoration(struct vtn_builder *b,
}
break;
- case SpvDecorationHlslSemanticGOOGLE:
- /* HLSL semantic decorations can safely be ignored by the driver. */
+ case SpvDecorationUserSemantic:
+ /* User semantic decorations can safely be ignored by the driver. */
break;
case SpvDecorationRestrictPointerEXT:
@@ -1615,8 +1615,8 @@ var_decoration_cb(struct vtn_builder *b, struct vtn_value *val, int member,
case SpvDecorationCoherent:
vtn_var->access |= ACCESS_COHERENT;
break;
- case SpvDecorationHlslCounterBufferGOOGLE:
- /* HLSL semantic decorations can safely be ignored by the driver. */
+ case SpvDecorationCounterBuffer:
+ /* Counter buffer decorations can safely be ignored by the driver. */
break;
default:
break;